{% extends "base.html" %}

{% block title %}Error {{ status_code }} - {{ site_name() }}{% endblock %}

{% block main_class %} sk-error-page{% endblock %}

{% block content %}
<article>
    <header>
        <h1>Error {{ status_code }}</h1>
    </header>

    <p>{{ message or "An unexpected error occurred." }}</p>

    {% if hint %}
    <details open>
        <summary>How to fix this</summary>
        {{ hint }}
    </details>
    {% endif %}

    <footer>
        <a href="/" role="button">Return Home</a>
    </footer>
</article>
{% endblock %}
